from . import rhbatch_pb2_grpc as importStub

class RhBatchService(object):

    def __init__(self, router):
        self.connector = router.get_connection(RhBatchService, importStub.RhBatchStub)

    def register(self, request, timeout=None):
        return self.connector.create_request('register', request, timeout)

    def unregister(self, request, timeout=None):
        return self.connector.create_request('unregister', request, timeout)

    def executeRhActionsBatch(self, request, timeout=None):
        return self.connector.create_request('executeRhActionsBatch', request, timeout)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_hand/rhactionsmessages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='th2_grpc_hand/rhactionsmessages.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n(com.exactpro.th2.act.grpc.hand.rhactionsB\021RhActionsMessagesP\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%th2_grpc_hand/rhactionsmessages.proto\"\x13\n\x04Open\x12\x0b\n\x03url\x18\x01 \x01(\t\"\xdd\x02\n\x05\x43lick\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\x1d\n\x06\x62utton\x18\x05 \x01(\x0e\x32\r.Click.Button\x12\x0f\n\x07xOffset\x18\x06 \x01(\x05\x12\x0f\n\x07yOffset\x18\x07 \x01(\x05\x12\'\n\tmodifiers\x18\x08 \x01(\x0b\x32\x14.Click.ModifiersList\x1aj\n\rModifiersList\x12/\n\x08modifier\x18\x01 \x03(\x0e\x32\x1d.Click.ModifiersList.Modifier\"(\n\x08Modifier\x12\x08\n\x04\x43TRL\x10\x00\x12\t\n\x05SHIFT\x10\x01\x12\x07\n\x03\x41LT\x10\x02\"5\n\x06\x42utton\x12\x08\n\x04LEFT\x10\x00\x12\t\n\x05RIGHT\x10\x01\x12\n\n\x06MIDDLE\x10\x02\x12\n\n\x06\x44OUBLE\x10\x03\"g\n\x0bSetCheckbox\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\x0f\n\x07\x63hecked\x18\x05 \x01(\x08\"\xfa\x01\n\x08SendKeys\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\r\n\x05wait2\x18\x06 \x01(\x05\x12\x1a\n\x08locator2\x18\x07 \x01(\x0e\x32\x08.Locator\x12\x10\n\x08matcher2\x18\x08 \x01(\t\x12\r\n\x05text2\x18\t \x01(\t\x12\x15\n\rcanBeDisabled\x18\n \x01(\x08\x12\r\n\x05\x63lear\x18\x0b \x01(\x08\x12\x12\n\ncheckInput\x18\x0c \x01(\x08\x12\x11\n\tneedClick\x18\r \x01(\x08\"\\\n\x0eWaitForElement\x12\x0f\n\x07seconds\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\"m\n\nWaitForNew\x12\x0f\n\x07seconds\x18\x01 \x01(\x05\x12\x13\n\x0b\x63heckMillis\x18\x02 \x01(\x05\x12\x19\n\x07locator\x18\x03 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x04 \x01(\t\x12\r\n\x05webId\x18\x05 \x01(\t\"\x17\n\x04Wait\x12\x0f\n\x07seconds\x18\x01 \x01(\x05\"a\n\nGetElement\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\"j\n\x13GetElementInnerHtml\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\"Z\n\x0fGetElementValue\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\"q\n\x13GetElementAttribute\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\x11\n\tattribute\x18\x05 \x01(\t\"Z\n\x0fGetDynamicTable\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\"S\n\x08ScrollTo\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\"\xa4\x01\n\x0bScrollDivTo\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\r\n\x05wait2\x18\x05 \x01(\x05\x12\x1a\n\x08locator2\x18\x06 \x01(\x0e\x32\x08.Locator\x12\x10\n\x08matcher2\x18\x07 \x01(\t\x12\x0f\n\x07yOffset\x18\x08 \x01(\x05\"\xa8\x02\n\x0eScrollDivUntil\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\r\n\x05wait2\x18\x05 \x01(\x05\x12\x1a\n\x08locator2\x18\x06 \x01(\x0e\x32\x08.Locator\x12\x10\n\x08matcher2\x18\x07 \x01(\t\x12,\n\tsearchDir\x18\x08 \x01(\x0e\x32\x19.ScrollDivUntil.Direction\x12\x14\n\x0csearchOffset\x18\t \x01(\x05\x12\x12\n\ndoScrollTo\x18\n \x01(\x08\x12\x0f\n\x07yOffset\x18\x0b \x01(\x05\"\'\n\tDirection\x12\x08\n\x04\x42OTH\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02\"\x0c\n\nPageSource\"\t\n\x07Refresh\"\x88\x01\n\x06Select\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x06 \x01(\t\x12\x16\n\x0enoOptionalFail\x18\x07 \x01(\x08\"W\n\x0c\x43learElement\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\"\x16\n\x06Output\x12\x0c\n\x04text\x18\x01 \x01(\t\"b\n\x0b\x46indElement\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\"m\n\tKeyAction\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\tkeyAction\x18\x02 \x01(\x0e\x32\x15.KeyAction.ActionType\")\n\nActionType\x12\t\n\x05PRESS\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02\"\x17\n\x08PressKey\x12\x0b\n\x03key\x18\x01 \x01(\t\"/\n\x10SendKeysToActive\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05text2\x18\x02 \x01(\t\"k\n\nUploadFile\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\x14\n\x0c\x61\x62solutePath\x18\x05 \x01(\t\"\x97\x01\n\x0c\x44ownloadFile\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x34\n\nactionType\x18\x02 \x01(\x0e\x32 .DownloadFile.DownloadActionType\x12\x11\n\tlocalPath\x18\x03 \x01(\x08\"0\n\x12\x44ownloadActionType\x12\x0c\n\x08SNAPSHOT\x10\x00\x12\x0c\n\x08\x44OWNLOAD\x10\x01\"\x1e\n\x0cSwitchWindow\x12\x0e\n\x06window\x18\x01 \x01(\x05\"\r\n\x0b\x43loseWindow\"\x0f\n\rGetCurrentURL\"\x18\n\x07SetZoom\x12\r\n\x05value\x18\x01 \x01(\t\"\x1b\n\rDurationStart\x12\n\n\x02id\x18\x01 \x01(\t\",\n\x0bGetDuration\x12\x0f\n\x07startId\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"h\n\x11StoreElementState\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\"\x87\x01\n\x0eWaitForChanges\x12\x0f\n\x07seconds\x18\x01 \x01(\x05\x12\x13\n\x0b\x63heckMillis\x18\x02 \x01(\x05\x12\x19\n\x07locator\x18\x03 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x04 \x01(\t\x12\r\n\x05webId\x18\x05 \x01(\t\x12\x14\n\x0cscreenshotId\x18\x06 \x01(\t\"\x1b\n\x0b\x41\x63\x63\x65ptAlert\x12\x0c\n\x04wait\x18\x01 \x01(\x05\"\x1c\n\x0c\x44ismissAlert\x12\x0c\n\x04wait\x18\x01 \x01(\x05\"a\n\x16\x43heckImageAvailability\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\"\x1d\n\rGetScreenshot\x12\x0c\n\x04name\x18\x01 \x01(\t\"m\n\x14GetElementScreenshot\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"\x1d\n\tExecuteJS\x12\x10\n\x08\x63ommands\x18\x01 \x01(\t\"m\n\x10\x45xecuteJSElement\x12\x0c\n\x04wait\x18\x01 \x01(\x05\x12\x19\n\x07locator\x18\x02 \x01(\x0e\x32\x08.Locator\x12\x0f\n\x07matcher\x18\x03 \x01(\t\x12\r\n\x05webId\x18\x04 \x01(\t\x12\x10\n\x08\x63ommands\x18\x05 \x01(\t*I\n\x07Locator\x12\x0b\n\x07NOT_SET\x10\x00\x12\x10\n\x0c\x43SS_SELECTOR\x10\x01\x12\x0c\n\x08TAG_NAME\x10\x02\x12\x06\n\x02ID\x10\x03\x12\t\n\x05XPATH\x10\x04\x42?\n(com.exactpro.th2.act.grpc.hand.rhactionsB\x11RhActionsMessagesP\x00\x62\x06proto3'
)

_LOCATOR = _descriptor.EnumDescriptor(
  name='Locator',
  full_name='Locator',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CSS_SELECTOR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TAG_NAME', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='XPATH', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3735,
  serialized_end=3808,
)
_sym_db.RegisterEnumDescriptor(_LOCATOR)

Locator = enum_type_wrapper.EnumTypeWrapper(_LOCATOR)
NOT_SET = 0
CSS_SELECTOR = 1
TAG_NAME = 2
ID = 3
XPATH = 4


_CLICK_MODIFIERSLIST_MODIFIER = _descriptor.EnumDescriptor(
  name='Modifier',
  full_name='Click.ModifiersList.Modifier',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CTRL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=317,
  serialized_end=357,
)
_sym_db.RegisterEnumDescriptor(_CLICK_MODIFIERSLIST_MODIFIER)

_CLICK_BUTTON = _descriptor.EnumDescriptor(
  name='Button',
  full_name='Click.Button',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIDDLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=359,
  serialized_end=412,
)
_sym_db.RegisterEnumDescriptor(_CLICK_BUTTON)

_SCROLLDIVUNTIL_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='ScrollDivUntil.Direction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOTH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2018,
  serialized_end=2057,
)
_sym_db.RegisterEnumDescriptor(_SCROLLDIVUNTIL_DIRECTION)

_KEYACTION_ACTIONTYPE = _descriptor.EnumDescriptor(
  name='ActionType',
  full_name='KeyAction.ActionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2504,
  serialized_end=2545,
)
_sym_db.RegisterEnumDescriptor(_KEYACTION_ACTIONTYPE)

_DOWNLOADFILE_DOWNLOADACTIONTYPE = _descriptor.EnumDescriptor(
  name='DownloadActionType',
  full_name='DownloadFile.DownloadActionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SNAPSHOT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOAD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2834,
  serialized_end=2882,
)
_sym_db.RegisterEnumDescriptor(_DOWNLOADFILE_DOWNLOADACTIONTYPE)


_OPEN = _descriptor.Descriptor(
  name='Open',
  full_name='Open',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='Open.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=60,
)


_CLICK_MODIFIERSLIST = _descriptor.Descriptor(
  name='ModifiersList',
  full_name='Click.ModifiersList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='modifier', full_name='Click.ModifiersList.modifier', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLICK_MODIFIERSLIST_MODIFIER,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=357,
)

_CLICK = _descriptor.Descriptor(
  name='Click',
  full_name='Click',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='Click.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='Click.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='Click.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='Click.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button', full_name='Click.button', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xOffset', full_name='Click.xOffset', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yOffset', full_name='Click.yOffset', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modifiers', full_name='Click.modifiers', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLICK_MODIFIERSLIST, ],
  enum_types=[
    _CLICK_BUTTON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=412,
)


_SETCHECKBOX = _descriptor.Descriptor(
  name='SetCheckbox',
  full_name='SetCheckbox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='SetCheckbox.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='SetCheckbox.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='SetCheckbox.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='SetCheckbox.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checked', full_name='SetCheckbox.checked', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=517,
)


_SENDKEYS = _descriptor.Descriptor(
  name='SendKeys',
  full_name='SendKeys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='SendKeys.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='SendKeys.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='SendKeys.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='SendKeys.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='SendKeys.text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait2', full_name='SendKeys.wait2', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator2', full_name='SendKeys.locator2', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher2', full_name='SendKeys.matcher2', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text2', full_name='SendKeys.text2', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='canBeDisabled', full_name='SendKeys.canBeDisabled', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear', full_name='SendKeys.clear', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkInput', full_name='SendKeys.checkInput', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='needClick', full_name='SendKeys.needClick', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=770,
)


_WAITFORELEMENT = _descriptor.Descriptor(
  name='WaitForElement',
  full_name='WaitForElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='WaitForElement.seconds', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='WaitForElement.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='WaitForElement.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='WaitForElement.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=772,
  serialized_end=864,
)


_WAITFORNEW = _descriptor.Descriptor(
  name='WaitForNew',
  full_name='WaitForNew',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='WaitForNew.seconds', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkMillis', full_name='WaitForNew.checkMillis', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='WaitForNew.locator', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='WaitForNew.matcher', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='WaitForNew.webId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=975,
)


_WAIT = _descriptor.Descriptor(
  name='Wait',
  full_name='Wait',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='Wait.seconds', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=977,
  serialized_end=1000,
)


_GETELEMENT = _descriptor.Descriptor(
  name='GetElement',
  full_name='GetElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='GetElement.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='GetElement.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='GetElement.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='GetElement.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='GetElement.id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1002,
  serialized_end=1099,
)


_GETELEMENTINNERHTML = _descriptor.Descriptor(
  name='GetElementInnerHtml',
  full_name='GetElementInnerHtml',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='GetElementInnerHtml.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='GetElementInnerHtml.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='GetElementInnerHtml.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='GetElementInnerHtml.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='GetElementInnerHtml.id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1207,
)


_GETELEMENTVALUE = _descriptor.Descriptor(
  name='GetElementValue',
  full_name='GetElementValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='GetElementValue.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='GetElementValue.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='GetElementValue.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='GetElementValue.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1209,
  serialized_end=1299,
)


_GETELEMENTATTRIBUTE = _descriptor.Descriptor(
  name='GetElementAttribute',
  full_name='GetElementAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='GetElementAttribute.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='GetElementAttribute.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='GetElementAttribute.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='GetElementAttribute.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='GetElementAttribute.attribute', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1301,
  serialized_end=1414,
)


_GETDYNAMICTABLE = _descriptor.Descriptor(
  name='GetDynamicTable',
  full_name='GetDynamicTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='GetDynamicTable.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='GetDynamicTable.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='GetDynamicTable.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='GetDynamicTable.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1416,
  serialized_end=1506,
)


_SCROLLTO = _descriptor.Descriptor(
  name='ScrollTo',
  full_name='ScrollTo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='ScrollTo.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='ScrollTo.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='ScrollTo.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='ScrollTo.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1508,
  serialized_end=1591,
)


_SCROLLDIVTO = _descriptor.Descriptor(
  name='ScrollDivTo',
  full_name='ScrollDivTo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='ScrollDivTo.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='ScrollDivTo.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='ScrollDivTo.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='ScrollDivTo.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait2', full_name='ScrollDivTo.wait2', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator2', full_name='ScrollDivTo.locator2', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher2', full_name='ScrollDivTo.matcher2', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yOffset', full_name='ScrollDivTo.yOffset', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1594,
  serialized_end=1758,
)


_SCROLLDIVUNTIL = _descriptor.Descriptor(
  name='ScrollDivUntil',
  full_name='ScrollDivUntil',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='ScrollDivUntil.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='ScrollDivUntil.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='ScrollDivUntil.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='ScrollDivUntil.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait2', full_name='ScrollDivUntil.wait2', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator2', full_name='ScrollDivUntil.locator2', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher2', full_name='ScrollDivUntil.matcher2', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchDir', full_name='ScrollDivUntil.searchDir', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchOffset', full_name='ScrollDivUntil.searchOffset', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doScrollTo', full_name='ScrollDivUntil.doScrollTo', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yOffset', full_name='ScrollDivUntil.yOffset', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCROLLDIVUNTIL_DIRECTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1761,
  serialized_end=2057,
)


_PAGESOURCE = _descriptor.Descriptor(
  name='PageSource',
  full_name='PageSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2059,
  serialized_end=2071,
)


_REFRESH = _descriptor.Descriptor(
  name='Refresh',
  full_name='Refresh',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2073,
  serialized_end=2082,
)


_SELECT = _descriptor.Descriptor(
  name='Select',
  full_name='Select',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='Select.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='Select.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='Select.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='Select.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='Select.text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default', full_name='Select.default', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='noOptionalFail', full_name='Select.noOptionalFail', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2085,
  serialized_end=2221,
)


_CLEARELEMENT = _descriptor.Descriptor(
  name='ClearElement',
  full_name='ClearElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='ClearElement.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='ClearElement.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='ClearElement.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='ClearElement.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2223,
  serialized_end=2310,
)


_OUTPUT = _descriptor.Descriptor(
  name='Output',
  full_name='Output',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='Output.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2312,
  serialized_end=2334,
)


_FINDELEMENT = _descriptor.Descriptor(
  name='FindElement',
  full_name='FindElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='FindElement.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='FindElement.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='FindElement.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='FindElement.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='FindElement.id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2336,
  serialized_end=2434,
)


_KEYACTION = _descriptor.Descriptor(
  name='KeyAction',
  full_name='KeyAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='KeyAction.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keyAction', full_name='KeyAction.keyAction', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _KEYACTION_ACTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2436,
  serialized_end=2545,
)


_PRESSKEY = _descriptor.Descriptor(
  name='PressKey',
  full_name='PressKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='PressKey.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2547,
  serialized_end=2570,
)


_SENDKEYSTOACTIVE = _descriptor.Descriptor(
  name='SendKeysToActive',
  full_name='SendKeysToActive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='SendKeysToActive.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text2', full_name='SendKeysToActive.text2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2572,
  serialized_end=2619,
)


_UPLOADFILE = _descriptor.Descriptor(
  name='UploadFile',
  full_name='UploadFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='UploadFile.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='UploadFile.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='UploadFile.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='UploadFile.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='absolutePath', full_name='UploadFile.absolutePath', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2621,
  serialized_end=2728,
)


_DOWNLOADFILE = _descriptor.Descriptor(
  name='DownloadFile',
  full_name='DownloadFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='DownloadFile.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actionType', full_name='DownloadFile.actionType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localPath', full_name='DownloadFile.localPath', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DOWNLOADFILE_DOWNLOADACTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2731,
  serialized_end=2882,
)


_SWITCHWINDOW = _descriptor.Descriptor(
  name='SwitchWindow',
  full_name='SwitchWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='window', full_name='SwitchWindow.window', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2884,
  serialized_end=2914,
)


_CLOSEWINDOW = _descriptor.Descriptor(
  name='CloseWindow',
  full_name='CloseWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2916,
  serialized_end=2929,
)


_GETCURRENTURL = _descriptor.Descriptor(
  name='GetCurrentURL',
  full_name='GetCurrentURL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2931,
  serialized_end=2946,
)


_SETZOOM = _descriptor.Descriptor(
  name='SetZoom',
  full_name='SetZoom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='SetZoom.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2948,
  serialized_end=2972,
)


_DURATIONSTART = _descriptor.Descriptor(
  name='DurationStart',
  full_name='DurationStart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='DurationStart.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2974,
  serialized_end=3001,
)


_GETDURATION = _descriptor.Descriptor(
  name='GetDuration',
  full_name='GetDuration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='startId', full_name='GetDuration.startId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='GetDuration.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3003,
  serialized_end=3047,
)


_STOREELEMENTSTATE = _descriptor.Descriptor(
  name='StoreElementState',
  full_name='StoreElementState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='StoreElementState.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='StoreElementState.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='StoreElementState.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='StoreElementState.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='StoreElementState.id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3049,
  serialized_end=3153,
)


_WAITFORCHANGES = _descriptor.Descriptor(
  name='WaitForChanges',
  full_name='WaitForChanges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='WaitForChanges.seconds', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkMillis', full_name='WaitForChanges.checkMillis', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='WaitForChanges.locator', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='WaitForChanges.matcher', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='WaitForChanges.webId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screenshotId', full_name='WaitForChanges.screenshotId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3156,
  serialized_end=3291,
)


_ACCEPTALERT = _descriptor.Descriptor(
  name='AcceptAlert',
  full_name='AcceptAlert',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='AcceptAlert.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3293,
  serialized_end=3320,
)


_DISMISSALERT = _descriptor.Descriptor(
  name='DismissAlert',
  full_name='DismissAlert',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='DismissAlert.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3322,
  serialized_end=3350,
)


_CHECKIMAGEAVAILABILITY = _descriptor.Descriptor(
  name='CheckImageAvailability',
  full_name='CheckImageAvailability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='CheckImageAvailability.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='CheckImageAvailability.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='CheckImageAvailability.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='CheckImageAvailability.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3352,
  serialized_end=3449,
)


_GETSCREENSHOT = _descriptor.Descriptor(
  name='GetScreenshot',
  full_name='GetScreenshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='GetScreenshot.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3451,
  serialized_end=3480,
)


_GETELEMENTSCREENSHOT = _descriptor.Descriptor(
  name='GetElementScreenshot',
  full_name='GetElementScreenshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='GetElementScreenshot.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='GetElementScreenshot.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='GetElementScreenshot.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='GetElementScreenshot.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='GetElementScreenshot.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3482,
  serialized_end=3591,
)


_EXECUTEJS = _descriptor.Descriptor(
  name='ExecuteJS',
  full_name='ExecuteJS',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commands', full_name='ExecuteJS.commands', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3593,
  serialized_end=3622,
)


_EXECUTEJSELEMENT = _descriptor.Descriptor(
  name='ExecuteJSElement',
  full_name='ExecuteJSElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait', full_name='ExecuteJSElement.wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator', full_name='ExecuteJSElement.locator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='ExecuteJSElement.matcher', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webId', full_name='ExecuteJSElement.webId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commands', full_name='ExecuteJSElement.commands', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3624,
  serialized_end=3733,
)

_CLICK_MODIFIERSLIST.fields_by_name['modifier'].enum_type = _CLICK_MODIFIERSLIST_MODIFIER
_CLICK_MODIFIERSLIST.containing_type = _CLICK
_CLICK_MODIFIERSLIST_MODIFIER.containing_type = _CLICK_MODIFIERSLIST
_CLICK.fields_by_name['locator'].enum_type = _LOCATOR
_CLICK.fields_by_name['button'].enum_type = _CLICK_BUTTON
_CLICK.fields_by_name['modifiers'].message_type = _CLICK_MODIFIERSLIST
_CLICK_BUTTON.containing_type = _CLICK
_SETCHECKBOX.fields_by_name['locator'].enum_type = _LOCATOR
_SENDKEYS.fields_by_name['locator'].enum_type = _LOCATOR
_SENDKEYS.fields_by_name['locator2'].enum_type = _LOCATOR
_WAITFORELEMENT.fields_by_name['locator'].enum_type = _LOCATOR
_WAITFORNEW.fields_by_name['locator'].enum_type = _LOCATOR
_GETELEMENT.fields_by_name['locator'].enum_type = _LOCATOR
_GETELEMENTINNERHTML.fields_by_name['locator'].enum_type = _LOCATOR
_GETELEMENTVALUE.fields_by_name['locator'].enum_type = _LOCATOR
_GETELEMENTATTRIBUTE.fields_by_name['locator'].enum_type = _LOCATOR
_GETDYNAMICTABLE.fields_by_name['locator'].enum_type = _LOCATOR
_SCROLLTO.fields_by_name['locator'].enum_type = _LOCATOR
_SCROLLDIVTO.fields_by_name['locator'].enum_type = _LOCATOR
_SCROLLDIVTO.fields_by_name['locator2'].enum_type = _LOCATOR
_SCROLLDIVUNTIL.fields_by_name['locator'].enum_type = _LOCATOR
_SCROLLDIVUNTIL.fields_by_name['locator2'].enum_type = _LOCATOR
_SCROLLDIVUNTIL.fields_by_name['searchDir'].enum_type = _SCROLLDIVUNTIL_DIRECTION
_SCROLLDIVUNTIL_DIRECTION.containing_type = _SCROLLDIVUNTIL
_SELECT.fields_by_name['locator'].enum_type = _LOCATOR
_CLEARELEMENT.fields_by_name['locator'].enum_type = _LOCATOR
_FINDELEMENT.fields_by_name['locator'].enum_type = _LOCATOR
_KEYACTION.fields_by_name['keyAction'].enum_type = _KEYACTION_ACTIONTYPE
_KEYACTION_ACTIONTYPE.containing_type = _KEYACTION
_UPLOADFILE.fields_by_name['locator'].enum_type = _LOCATOR
_DOWNLOADFILE.fields_by_name['actionType'].enum_type = _DOWNLOADFILE_DOWNLOADACTIONTYPE
_DOWNLOADFILE_DOWNLOADACTIONTYPE.containing_type = _DOWNLOADFILE
_STOREELEMENTSTATE.fields_by_name['locator'].enum_type = _LOCATOR
_WAITFORCHANGES.fields_by_name['locator'].enum_type = _LOCATOR
_CHECKIMAGEAVAILABILITY.fields_by_name['locator'].enum_type = _LOCATOR
_GETELEMENTSCREENSHOT.fields_by_name['locator'].enum_type = _LOCATOR
_EXECUTEJSELEMENT.fields_by_name['locator'].enum_type = _LOCATOR
DESCRIPTOR.message_types_by_name['Open'] = _OPEN
DESCRIPTOR.message_types_by_name['Click'] = _CLICK
DESCRIPTOR.message_types_by_name['SetCheckbox'] = _SETCHECKBOX
DESCRIPTOR.message_types_by_name['SendKeys'] = _SENDKEYS
DESCRIPTOR.message_types_by_name['WaitForElement'] = _WAITFORELEMENT
DESCRIPTOR.message_types_by_name['WaitForNew'] = _WAITFORNEW
DESCRIPTOR.message_types_by_name['Wait'] = _WAIT
DESCRIPTOR.message_types_by_name['GetElement'] = _GETELEMENT
DESCRIPTOR.message_types_by_name['GetElementInnerHtml'] = _GETELEMENTINNERHTML
DESCRIPTOR.message_types_by_name['GetElementValue'] = _GETELEMENTVALUE
DESCRIPTOR.message_types_by_name['GetElementAttribute'] = _GETELEMENTATTRIBUTE
DESCRIPTOR.message_types_by_name['GetDynamicTable'] = _GETDYNAMICTABLE
DESCRIPTOR.message_types_by_name['ScrollTo'] = _SCROLLTO
DESCRIPTOR.message_types_by_name['ScrollDivTo'] = _SCROLLDIVTO
DESCRIPTOR.message_types_by_name['ScrollDivUntil'] = _SCROLLDIVUNTIL
DESCRIPTOR.message_types_by_name['PageSource'] = _PAGESOURCE
DESCRIPTOR.message_types_by_name['Refresh'] = _REFRESH
DESCRIPTOR.message_types_by_name['Select'] = _SELECT
DESCRIPTOR.message_types_by_name['ClearElement'] = _CLEARELEMENT
DESCRIPTOR.message_types_by_name['Output'] = _OUTPUT
DESCRIPTOR.message_types_by_name['FindElement'] = _FINDELEMENT
DESCRIPTOR.message_types_by_name['KeyAction'] = _KEYACTION
DESCRIPTOR.message_types_by_name['PressKey'] = _PRESSKEY
DESCRIPTOR.message_types_by_name['SendKeysToActive'] = _SENDKEYSTOACTIVE
DESCRIPTOR.message_types_by_name['UploadFile'] = _UPLOADFILE
DESCRIPTOR.message_types_by_name['DownloadFile'] = _DOWNLOADFILE
DESCRIPTOR.message_types_by_name['SwitchWindow'] = _SWITCHWINDOW
DESCRIPTOR.message_types_by_name['CloseWindow'] = _CLOSEWINDOW
DESCRIPTOR.message_types_by_name['GetCurrentURL'] = _GETCURRENTURL
DESCRIPTOR.message_types_by_name['SetZoom'] = _SETZOOM
DESCRIPTOR.message_types_by_name['DurationStart'] = _DURATIONSTART
DESCRIPTOR.message_types_by_name['GetDuration'] = _GETDURATION
DESCRIPTOR.message_types_by_name['StoreElementState'] = _STOREELEMENTSTATE
DESCRIPTOR.message_types_by_name['WaitForChanges'] = _WAITFORCHANGES
DESCRIPTOR.message_types_by_name['AcceptAlert'] = _ACCEPTALERT
DESCRIPTOR.message_types_by_name['DismissAlert'] = _DISMISSALERT
DESCRIPTOR.message_types_by_name['CheckImageAvailability'] = _CHECKIMAGEAVAILABILITY
DESCRIPTOR.message_types_by_name['GetScreenshot'] = _GETSCREENSHOT
DESCRIPTOR.message_types_by_name['GetElementScreenshot'] = _GETELEMENTSCREENSHOT
DESCRIPTOR.message_types_by_name['ExecuteJS'] = _EXECUTEJS
DESCRIPTOR.message_types_by_name['ExecuteJSElement'] = _EXECUTEJSELEMENT
DESCRIPTOR.enum_types_by_name['Locator'] = _LOCATOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Open = _reflection.GeneratedProtocolMessageType('Open', (_message.Message,), {
  'DESCRIPTOR' : _OPEN,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:Open)
  })
_sym_db.RegisterMessage(Open)

Click = _reflection.GeneratedProtocolMessageType('Click', (_message.Message,), {

  'ModifiersList' : _reflection.GeneratedProtocolMessageType('ModifiersList', (_message.Message,), {
    'DESCRIPTOR' : _CLICK_MODIFIERSLIST,
    '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
    # @@protoc_insertion_point(class_scope:Click.ModifiersList)
    })
  ,
  'DESCRIPTOR' : _CLICK,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:Click)
  })
_sym_db.RegisterMessage(Click)
_sym_db.RegisterMessage(Click.ModifiersList)

SetCheckbox = _reflection.GeneratedProtocolMessageType('SetCheckbox', (_message.Message,), {
  'DESCRIPTOR' : _SETCHECKBOX,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:SetCheckbox)
  })
_sym_db.RegisterMessage(SetCheckbox)

SendKeys = _reflection.GeneratedProtocolMessageType('SendKeys', (_message.Message,), {
  'DESCRIPTOR' : _SENDKEYS,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:SendKeys)
  })
_sym_db.RegisterMessage(SendKeys)

WaitForElement = _reflection.GeneratedProtocolMessageType('WaitForElement', (_message.Message,), {
  'DESCRIPTOR' : _WAITFORELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:WaitForElement)
  })
_sym_db.RegisterMessage(WaitForElement)

WaitForNew = _reflection.GeneratedProtocolMessageType('WaitForNew', (_message.Message,), {
  'DESCRIPTOR' : _WAITFORNEW,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:WaitForNew)
  })
_sym_db.RegisterMessage(WaitForNew)

Wait = _reflection.GeneratedProtocolMessageType('Wait', (_message.Message,), {
  'DESCRIPTOR' : _WAIT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:Wait)
  })
_sym_db.RegisterMessage(Wait)

GetElement = _reflection.GeneratedProtocolMessageType('GetElement', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:GetElement)
  })
_sym_db.RegisterMessage(GetElement)

GetElementInnerHtml = _reflection.GeneratedProtocolMessageType('GetElementInnerHtml', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTINNERHTML,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:GetElementInnerHtml)
  })
_sym_db.RegisterMessage(GetElementInnerHtml)

GetElementValue = _reflection.GeneratedProtocolMessageType('GetElementValue', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTVALUE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:GetElementValue)
  })
_sym_db.RegisterMessage(GetElementValue)

GetElementAttribute = _reflection.GeneratedProtocolMessageType('GetElementAttribute', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTATTRIBUTE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:GetElementAttribute)
  })
_sym_db.RegisterMessage(GetElementAttribute)

GetDynamicTable = _reflection.GeneratedProtocolMessageType('GetDynamicTable', (_message.Message,), {
  'DESCRIPTOR' : _GETDYNAMICTABLE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:GetDynamicTable)
  })
_sym_db.RegisterMessage(GetDynamicTable)

ScrollTo = _reflection.GeneratedProtocolMessageType('ScrollTo', (_message.Message,), {
  'DESCRIPTOR' : _SCROLLTO,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:ScrollTo)
  })
_sym_db.RegisterMessage(ScrollTo)

ScrollDivTo = _reflection.GeneratedProtocolMessageType('ScrollDivTo', (_message.Message,), {
  'DESCRIPTOR' : _SCROLLDIVTO,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:ScrollDivTo)
  })
_sym_db.RegisterMessage(ScrollDivTo)

ScrollDivUntil = _reflection.GeneratedProtocolMessageType('ScrollDivUntil', (_message.Message,), {
  'DESCRIPTOR' : _SCROLLDIVUNTIL,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:ScrollDivUntil)
  })
_sym_db.RegisterMessage(ScrollDivUntil)

PageSource = _reflection.GeneratedProtocolMessageType('PageSource', (_message.Message,), {
  'DESCRIPTOR' : _PAGESOURCE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:PageSource)
  })
_sym_db.RegisterMessage(PageSource)

Refresh = _reflection.GeneratedProtocolMessageType('Refresh', (_message.Message,), {
  'DESCRIPTOR' : _REFRESH,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:Refresh)
  })
_sym_db.RegisterMessage(Refresh)

Select = _reflection.GeneratedProtocolMessageType('Select', (_message.Message,), {
  'DESCRIPTOR' : _SELECT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:Select)
  })
_sym_db.RegisterMessage(Select)

ClearElement = _reflection.GeneratedProtocolMessageType('ClearElement', (_message.Message,), {
  'DESCRIPTOR' : _CLEARELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:ClearElement)
  })
_sym_db.RegisterMessage(ClearElement)

Output = _reflection.GeneratedProtocolMessageType('Output', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:Output)
  })
_sym_db.RegisterMessage(Output)

FindElement = _reflection.GeneratedProtocolMessageType('FindElement', (_message.Message,), {
  'DESCRIPTOR' : _FINDELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:FindElement)
  })
_sym_db.RegisterMessage(FindElement)

KeyAction = _reflection.GeneratedProtocolMessageType('KeyAction', (_message.Message,), {
  'DESCRIPTOR' : _KEYACTION,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:KeyAction)
  })
_sym_db.RegisterMessage(KeyAction)

PressKey = _reflection.GeneratedProtocolMessageType('PressKey', (_message.Message,), {
  'DESCRIPTOR' : _PRESSKEY,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:PressKey)
  })
_sym_db.RegisterMessage(PressKey)

SendKeysToActive = _reflection.GeneratedProtocolMessageType('SendKeysToActive', (_message.Message,), {
  'DESCRIPTOR' : _SENDKEYSTOACTIVE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:SendKeysToActive)
  })
_sym_db.RegisterMessage(SendKeysToActive)

UploadFile = _reflection.GeneratedProtocolMessageType('UploadFile', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADFILE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:UploadFile)
  })
_sym_db.RegisterMessage(UploadFile)

DownloadFile = _reflection.GeneratedProtocolMessageType('DownloadFile', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADFILE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:DownloadFile)
  })
_sym_db.RegisterMessage(DownloadFile)

SwitchWindow = _reflection.GeneratedProtocolMessageType('SwitchWindow', (_message.Message,), {
  'DESCRIPTOR' : _SWITCHWINDOW,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:SwitchWindow)
  })
_sym_db.RegisterMessage(SwitchWindow)

CloseWindow = _reflection.GeneratedProtocolMessageType('CloseWindow', (_message.Message,), {
  'DESCRIPTOR' : _CLOSEWINDOW,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:CloseWindow)
  })
_sym_db.RegisterMessage(CloseWindow)

GetCurrentURL = _reflection.GeneratedProtocolMessageType('GetCurrentURL', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTURL,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:GetCurrentURL)
  })
_sym_db.RegisterMessage(GetCurrentURL)

SetZoom = _reflection.GeneratedProtocolMessageType('SetZoom', (_message.Message,), {
  'DESCRIPTOR' : _SETZOOM,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:SetZoom)
  })
_sym_db.RegisterMessage(SetZoom)

DurationStart = _reflection.GeneratedProtocolMessageType('DurationStart', (_message.Message,), {
  'DESCRIPTOR' : _DURATIONSTART,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:DurationStart)
  })
_sym_db.RegisterMessage(DurationStart)

GetDuration = _reflection.GeneratedProtocolMessageType('GetDuration', (_message.Message,), {
  'DESCRIPTOR' : _GETDURATION,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:GetDuration)
  })
_sym_db.RegisterMessage(GetDuration)

StoreElementState = _reflection.GeneratedProtocolMessageType('StoreElementState', (_message.Message,), {
  'DESCRIPTOR' : _STOREELEMENTSTATE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:StoreElementState)
  })
_sym_db.RegisterMessage(StoreElementState)

WaitForChanges = _reflection.GeneratedProtocolMessageType('WaitForChanges', (_message.Message,), {
  'DESCRIPTOR' : _WAITFORCHANGES,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:WaitForChanges)
  })
_sym_db.RegisterMessage(WaitForChanges)

AcceptAlert = _reflection.GeneratedProtocolMessageType('AcceptAlert', (_message.Message,), {
  'DESCRIPTOR' : _ACCEPTALERT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:AcceptAlert)
  })
_sym_db.RegisterMessage(AcceptAlert)

DismissAlert = _reflection.GeneratedProtocolMessageType('DismissAlert', (_message.Message,), {
  'DESCRIPTOR' : _DISMISSALERT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:DismissAlert)
  })
_sym_db.RegisterMessage(DismissAlert)

CheckImageAvailability = _reflection.GeneratedProtocolMessageType('CheckImageAvailability', (_message.Message,), {
  'DESCRIPTOR' : _CHECKIMAGEAVAILABILITY,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:CheckImageAvailability)
  })
_sym_db.RegisterMessage(CheckImageAvailability)

GetScreenshot = _reflection.GeneratedProtocolMessageType('GetScreenshot', (_message.Message,), {
  'DESCRIPTOR' : _GETSCREENSHOT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:GetScreenshot)
  })
_sym_db.RegisterMessage(GetScreenshot)

GetElementScreenshot = _reflection.GeneratedProtocolMessageType('GetElementScreenshot', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTSCREENSHOT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:GetElementScreenshot)
  })
_sym_db.RegisterMessage(GetElementScreenshot)

ExecuteJS = _reflection.GeneratedProtocolMessageType('ExecuteJS', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEJS,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:ExecuteJS)
  })
_sym_db.RegisterMessage(ExecuteJS)

ExecuteJSElement = _reflection.GeneratedProtocolMessageType('ExecuteJSElement', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEJSELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_pb2'
  # @@protoc_insertion_point(class_scope:ExecuteJSElement)
  })
_sym_db.RegisterMessage(ExecuteJSElement)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
